#
# spec file for package python-radon
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-radon
Version:        6.0.1
Release:        1.3
Summary:        Code Metrics in Python
License:        MIT
URL:            https://github.com/rubik/radon
Source:         https://files.pythonhosted.org/packages/source/r/radon/radon-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#rubik/radon#250
Patch0:         add-scripts-to-pyproject.toml.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-colorama >= 0.4.1
Requires:       python-mando >= 0.6
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module colorama >= 0.4.1}
BuildRequires:  %{python_module mando >= 0.6}
BuildRequires:  %{python_module pytest >= 2.7}
BuildRequires:  %{python_module pytest-mock}
# /SECTION
%python_subpackages

%description
Radon is a Python tool that computes various metrics from the source code.
Radon can compute:

* McCabe's complexity**, i.e. cyclomatic complexity
* raw metrics (these include SLOC, comment lines, blank lines, &c.)
* Halstead metrics (all of them)
* Maintainability Index (the one used in Visual Studio)

%prep
%autosetup -p1 -n radon-%{version}
# unpin mando
sed -i -E 's/(mando.*),<0\.7/\1/' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/radon

%check
%pytest

%post
%python_install_alternative radon

%postun
%python_uninstall_alternative radon

%files %{python_files}
%doc CHANGELOG README.rst
%license LICENSE
%python_alternative %{_bindir}/radon
%{python_sitelib}/radon
%{python_sitelib}/radon-%{version}.dist-info

%changelog
* Fri Sep  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.0.1:
  * Prevent tomllib error when the `toml` module is not available
  * Add support for `match` pattern in Python 3.10+, by @DolajoCZ: #227
  * Fix typo in Markdown export, reported by @huornlmj: #231
  * Remove unnecessary "future" dependency, by @mgorny: #234
  * Add `pyproject.toml` support, by @ajslater: #236
  * Allow Mando v0.7.1, by @ajslater: #237
  * Fix HCHarvester JSON results format, by @benabel: #240
- Use pyproject macros due to the switch to poetry.
- Add patch add-scripts-to-pyproject.toml.patch, make sure the CLI tool
  is built.
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Aug 25 2022 Ben Greiner <code@bnavigator.de>
- Update to 5.1.0
  * Allow forcing colored output on/off, thanks @msabramo: #218
  * Synchronize trove classifiers with tested versions, thanks
    @D3X: #222
- Release 5.0.1
  * Drop support for flake8 < 3.x (removes `flake8-polyfill`
  dependency), by @joxl: #219
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.5.2
  * Fix CC calculation for try-except-else blocks with multiple
    statements
  * Fix CC type field in Markdown output
* Fri May  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.5.0
  * Add `--md` option to `cc` command to export results as Markdown
  * Add async function support to Halstead visitor
  * Use utf-8 as the default encoding on Python 3.0+
  * Allow custom config file path through the RADONCFG env var
  * Move `Flake8Checker` to separate, isolated module
  * Separate `flake8-polyfill` to extra requirements
  * Fix for Python 2.7
* Tue Jan 28 2020 Matej Cepl <mcepl@suse.com>
- Update to 4.1.0: Support Python 3.8
* Thu Dec  5 2019 Matej Cepl <mcepl@suse.com>
- Exclude some tests cases because of gh#rubik/radon#183
* Tue Oct  1 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 4.0.0
  * Support file configuration overrides
  * Add support for analyzing Jupyter notebooks
* Fri May 24 2019 pgajdos@suse.com
- version update to 3.0.3
  * no upstream changelog
* Tue Mar  5 2019 Hans-Peter Jansen <hpj@urpla.net>
- set environment encoding for checks in order to succeed
  test_encoding with Python < 3.7
* Thu Feb 14 2019 John Vandenberg <jayvdb@gmail.com>
- Fix tests which were erroring but the error was being ignored
- Remove tests from the package
- Use GitHub repository for the link, as it has links to other
  resources
- Update to v3.0.1
  * Automatically exclude binary files, instead of producing an error
- from 3.0.0
  * Include files with no extension but a Python shebang
  * Fix calculation of total complexity for classes
  * Update Colorama dependency to avoid conflicts with pytest
  * Fix raw metrics, which were completely broken
* Sat Jan 19 2019 Michael Ströder <michael@stroeder.com>
- Update to 2.4.0
  * No upstream changelog
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 2.2.0
  * Add an option to show closures when Radon is used from flake8: #135
- spec file cleanups
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
